import {
  ContentfulClientApi,
  createClient,
  Entry,
  EntryCollection,
} from 'contentful'

const space = process.env.NEXT_PUBLIC_CONTENTFUL_SPACE_ID
const accessToken = process.env.NEXT_PUBLIC_CONTENTFUL_ACCESS_TOKEN

const client: ContentfulClientApi = createClient({
  space: space,
  accessToken: accessToken,
})

export type ServiceType = {
  name: string
  slug: string
  logo: object
  shortDescription: object
  developer: object
  contactInformation: object
  status: string
  documentationURL: string
  tags?: any[]
  sourcecodeURL?: string
  tosURL?: string
  description: object
}

export async function fetchServices(): Promise<Entry<any>[]> {
  const services = await client.getEntries({
    content_type: 'service',
  })
  if (services.items) return services.items
  console.log(`Error getting Entries for services.`)
}

export async function fetchService(slug): Promise<Entry<any>> {
  const services = await client.getEntries({
    content_type: 'service',
  })

  return services.items.find(
    (service: Entry<ServiceType>) => service.fields.slug === slug
  )
}

export default { fetchServices, fetchService }
